SWDEV-1 - Add missing checks in hipMemcpy2DAsync.cc

Bu işleme şunda yer alıyor:
Maneesh Gupta
2022-10-11 08:28:19 +05:30
işlemeyi yapan: GitHub
ebeveyn 8d0e6fd39f
işleme 1d1a4ddd3c
+2 -2
Dosyayı Görüntüle
@@ -160,7 +160,7 @@ TEMPLATE_TEST_CASE("Unit_hipMemcpy2DAsync_multiDevice-Host&PinnedMem", ""
hipStream_t stream; hipStream_t stream;
if (numDevices > 1) { if (numDevices > 1) {
hipDeviceCanAccessPeer(&canAccessPeer, 0, 1); HIP_CHECK(hipDeviceCanAccessPeer(&canAccessPeer, 0, 1));
if (canAccessPeer) { if (canAccessPeer) {
HIP_CHECK(hipSetDevice(0)); HIP_CHECK(hipSetDevice(0));
HIP_CHECK(hipStreamCreate(&stream)); HIP_CHECK(hipStreamCreate(&stream));
@@ -250,7 +250,7 @@ TEMPLATE_TEST_CASE("Unit_hipMemcpy2DAsync_multiDevice-StreamOnDiffDevice", ""
hipStream_t stream; hipStream_t stream;
if (numDevices > 1) { if (numDevices > 1) {
hipDeviceCanAccessPeer(&canAccessPeer, 0, 1); HIP_CHECK(hipDeviceCanAccessPeer(&canAccessPeer, 0, 1));
if (canAccessPeer) { if (canAccessPeer) {
HIP_CHECK(hipSetDevice(0)); HIP_CHECK(hipSetDevice(0));